@@ -77,13 +77,16 @@ NULL
 #' @examplesIf parallel::detectCores() < 9 && requireNamespace("dplyr")
 #' ## This example is to retain the duplicate entry which contains the least
 #' ## number of columns with NA values
+#' require(dplyr)
 #' mv <- mt_read(mt_example())
 #' mv <- dplyr::bind_rows(mv, mv[1:10, ])
 #' mv[, "eobs:used-time-to-get-fix"] <- NA
-#' mv_no_dup <- mv |>
-#'   dplyr::mutate(n_na = rowSums(is.na(pick(everything())))) |>
-#'   dplyr::arrange(n_na) |>
-#'   mt_filter_unique(criterion = "first")
+#' mv_no_dup <- mv %>%
+#'   mutate(n_na = rowSums(is.na(pick(everything())))) %>%
+#'   arrange(n_na) %>%
+#'   mt_filter_unique(criterion = "first") %>%
+#'   arrange(mt_track_id()) %>%
+#'   arrange(mt_track_id(), mt_time())
 mt_filter_unique <- function(x, ...) {
   x[mt_unique(x, ...), ]
 }
@@ -162,7 +165,7 @@ slice_subsets <- function(rws, x, equivalance_fun = identical, ...) {
     all(mapply(equivalance_fun, xx[[i[1]]], xx[[i[2]]], ...) | is.na(xx[[i[2]]]))
   }, xx = l, ...) # true when second record is equal or NA compared to first
   # remove records that are duplicated (in case using all.equal and pass first duplication test)
-  r[duplicated(cbind(t(apply(e, 1, sort)), r)) & r] <- F
+  r[duplicated(cbind(t(apply(e, 1, sort)), r)) & r] <- FALSE
   # omit all records that are subset of other
   return(rws[!(rws %in% unique(e[r, 2]))])
 }
